@@ -434,7 +434,7 @@ class Human:
         if image_analysis.get('recognition'):  # 新版本ai识别结果
             self.threshold = 0.05
             image_analysis['human_pose'] = self.add_new_crop_point(image_analysis.get("recognition"),
-                                                                     image_analysis.get("human_pose"))
+                                                                   image_analysis.get("human_pose"))
         self.image_width = None
         self.image_height = None
         self.human_body_width = None
@@ -483,11 +483,11 @@ class Human:
             left_mouth = face['landmarks'][3]  # 嘴的左边
             right_mouth = face['landmarks'][4]  # 嘴的右边
             # 嘴巴的中点
-            mouth_x = min(left_mouth[0], right_mouth[0]) + abs(left_mouth[0] - right_mouth[0])/2
+            mouth_x = min(left_mouth[0], right_mouth[0]) + abs(left_mouth[0] - right_mouth[0]) / 2
             mouth_y = max(left_mouth[1], right_mouth[1])
             # 下颚的点
             mandible_point[0] = mouth_x
-            mandible_point[1] = min(law_y, mouth_y) + abs(mouth_y - law_y)/2
+            mandible_point[1] = min(law_y, mouth_y) + abs(mouth_y - law_y) / 2
             mandible_point[2] = 1
             # print(mandible_point)
         else:
@@ -599,7 +599,8 @@ class Human:
                 # 嘴巴点 在 keypoints index 3 4
                 # 下巴点 在 bbox index  2 3
                 human_pose_result[i]['keypoints'].insert(self.HUMAN_BODY_KEY_POINTS.index('mandible'),
-                                                         self.calculate_mandible_crop_point(human['face'],human['keypoints']))
+                                                         self.calculate_mandible_crop_point(human['face'],
+                                                                                            human['keypoints']))
 
         human_pose_dict['result'] = human_pose_result
 
@@ -609,8 +610,6 @@ class Human:
         #     logging.error(f"ai识别结果-人体关键点-解析失败: {self.image_analysis} ", exc_info=True)
         return human_pose
 
-
-
     def deal_human_crop_point(self, crop_point_dict):
         '''
         处理人体的裁剪点，方便裁剪时取值
@@ -821,6 +820,7 @@ class Cloths:
         garment['cat_name'] = one_garment['cat_name']  # 服装分类name
         return garment
 
+
 class Brand:
     def __init__(self, image_analysis):
         self.image_analysis = image_analysis
@@ -836,6 +836,8 @@ class Brand:
         brand_list = []
         try:
             brand_info = json.loads(brand_json)
+            if not brand_info.get('labels'):
+                return []
             self.image_width, self.image_height = brand_info['image']['width'], brand_info['image']['height']
             for one_brand in brand_info['labels']:
                 if one_brand['confidence'] < self.threshold:  # 置信度过低
@@ -850,7 +852,6 @@ class Brand:
     def deal_brand(self, one_brand):
         '''处理下 每个资质图的 box cat_id cat_name confidence'''
 
-
         brand = dict()
 
         #  服装的区域
@@ -866,6 +867,15 @@ class Brand:
         return brand
 
     def deal_brand_crop_point(self):
+        if not self.brand_list:
+            return {
+                'brand_top': {
+                    'top_site': [0, 0], 'bottom_site': [1, 1]
+                },
+                'brand_bottom': {
+                    'top_site': [0, 0], 'bottom_site': [1, 1]
+                }}
+
         brand_crop_point_dict = {}
         for brand in self.brand_list:
             brand_crop_point_dict = self.brand_crop_point(brand, brand_crop_point_dict)
@@ -887,7 +897,7 @@ class Brand:
         brand_bottom_site = crop_point_dict['brand_bottom']['bottom_site']
         # 取最小
         crop_point_dict['brand_top']['top_site'] = min(brand_top_site[0], brand_box[0]), min(brand_top_site[1],
-                                                                                                 brand_box[1])
+                                                                                             brand_box[1])
         # 取最大
         crop_point_dict['brand_top']['bottom_site'] = max(brand_bottom_site[0], brand_box[2]), max(
             brand_bottom_site[1], brand_box[3])
